==> taxipilot-0.6.0.tar.gz: taxipilot-0.6.0/taxipilot/defines.h <==
/***************************************************************************
                          defines.h  -  description
                             -------------------
    begin                : Sun Sep 30 2001
    copyright            : (C) 2001 by Thomas Friedrichsmeier
    email                : Thomas.Friedrichsmeier@ruhr-uni-bochum.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// Defines: these might not all be in place yet, so some might not change anything!

// general defines

#define FPS					100
#define CPS					20
#define F_PER_C				5

// speed

#define TEXT_SPEED			300
#define ADVANCE_PERIOD		10
#define START_SCREEN_AP		20
#define CREDITS_SPEED		300
#define ACCELERATION			0.1

// timer-periods
#define BASE_TP				50
#define PASSENGER_TP  		5000
#define TEXT_TP				10
#define SCROLL_TP			10
#define CREDITS_TP			10
#define OBJECTS_AP			30
#define PASSENGER_AP		50

#define TAXI_FLAPS_TP			50

// position
#define LEVEL_Z 				50
#define TAXI_Z				75
#define TAXI_FLYING_Z			70
#define TAXI_FLAPS_Z			80
#define FADER_Z				100
#define MESSAGE_Z			110

// other
#define FUEL_UP_EMPTY_BY 	100

// size and font
#define LABEL_FONT			"helvetica"
#define LABEL_FONT_SIZE		16
#define CREDITS_FONT			"helvetica"
#define CREDITS_FONT_SIZE	16
#define CREDITS_FONT_COLOR	yellow
#define MESSAGE_FONT      		"helvetica"
	// this is maximum font size. Actual size might be lower to fit message on screen. see display_message ()
#define MESSAGE_FONT_SIZE 	24
#define SPACE_TEXT_FONT		"helvetica"
#define SPACE_TEXT_FONT_SIZE	14
#define SPACE_TEXT_COLOR	yellow
#define MESSAGE_COLOR		white

// message-defines and crash "how"-defines (in calls to crash (int how))
// don't mess with these, they're internal

#define GAME_OVER	 		1
#define NEXT_LEVEL			2
#define EXTRA_LIFE			4
#define CRASH				8
#define CRASH_BACKGR		16
#define CRASH_PASSENGER	32
#define MISSION_COMPLETE 	64
#define LOW_FUEL				128

==> taxipilot-0.7.2.tar.gz: taxipilot-0.7.2/taxipilot/defines.h <==
/***************************************************************************
                          defines.h  -  description
                             -------------------
    begin                : Sun Sep 30 2001
    copyright            : (C) 2001 by Thomas Friedrichsmeier
    email                : Thomas.Friedrichsmeier@ruhr-uni-bochum.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef DEFINES_H
#define DEFINES_H

// Defines: these might not all be in place yet, so some might not change anything!

// general defines

//#define FPS					100
//#define CPS					20
//#define F_PER_C				5

// speed

#define TEXT_SPEED			300
//#define ADVANCE_PERIOD		10
//#define START_SCREEN_AP		20
#define CREDITS_SPEED		250
#define ACCELERATION			0.1

// timer-periods
//#define BASE_TP				50
#define PASSENGER_TP  		5000
#define TEXT_TP				10
//#define SCROLL_TP			10
#define CREDITS_TP			10
#define OBJECTS_AP			30
#define PASSENGER_AP		50

#define TAXI_FLAPS_TP			50

// position
#define LEVEL_Z 				50
#define TAXI_Z				75
#define TAXI_FLYING_Z			70
#define TAXI_FLAPS_Z			80
#define FADER_Z				100
#define MESSAGE_Z			110
#define PASSENGER_Z		40

// other
#define FUEL_UP_EMPTY_BY 	100

// size and font
#define LABEL_FONT			"helvetica"
#define LABEL_FONT_SIZE		16
#define CREDITS_FONT			"helvetica"
#define CREDITS_FONT_SIZE	16
#define CREDITS_FONT_COLOR	yellow
#define MESSAGE_FONT      		"helvetica"
	// this is maximum font size. Actual size might be lower to fit message on screen. see display_message ()
#define MESSAGE_FONT_SIZE 	24
#define SPACE_TEXT_FONT		"helvetica"
#define SPACE_TEXT_FONT_SIZE	14
#define SPACE_TEXT_COLOR	yellow
#define MESSAGE_COLOR		white

// message-defines and crash "how"-defines (in calls to crash (int how))
// don't mess with these, they're internal

#define GAME_OVER	 		1
#define NEXT_LEVEL			2
#define EXTRA_LIFE			4
#define CRASH				8
#define CRASH_BACKGR		16
#define CRASH_PASSENGER	32
#define MISSION_COMPLETE 	64
#define LOW_FUEL				128
#define PAUSE				256


// Porting section:
#ifndef OLD_KDE
#define NEW_KDE
#endif

#ifdef NEW_KDE
#define KDE_NO_COMPAT
#define TOPEDGE topEdge
#define LEFTEDGE leftEdge
#define RIGHTEDGE rightEdge
#define BOTTOMEDGE bottomEdge
#define KSTDDIRS <kstandarddirs.h>
#define KAPP <kapplication.h>
#else
#define TOPEDGE absY
#define LEFTEDGE absX
#define RIGHTEDGE absX2
#define BOTTOMEDGE absY2
#define KSTDDIRS <kstddirs.h>
#define KAPP <kapp.h>
#endif


#endif
